@@ -1,6 +1,8 @@
 from .summarization import SummarizationMiddleware
 from .tool_selection import LLMToolSelectorMiddleware
 from .plan import PlanMiddleware, create_update_plan_tool, create_write_plan_tool
+from .model_fallback import ModelFallbackMiddleware
+from .tool_emulator import LLMToolEmulator
 
 __all__ = [
     "SummarizationMiddleware",
@@ -8,4 +10,6 @@ __all__ = [
     "PlanMiddleware",
     "create_update_plan_tool",
     "create_write_plan_tool",
+    "ModelFallbackMiddleware",
+    "LLMToolEmulator",
 ]
